@@ -151,7 +151,10 @@ class Context:
 
 
 def cleanup_elements_from_previous_pipeline_versions(
-    fetcher_project: Project, source_data_project: Project, json_data_project: Project, ctx: Context,
+    fetcher_project: Project,
+    source_data_project: Project,
+    json_data_project: Project,
+    ctx: Context,
 ) -> None:
     """Cleanup elements from pipelines v1 or v2.
 
@@ -283,6 +286,7 @@ def find_variable_by_name(project: Project, name: str) -> Optional[Variable]:
 def find_deploy_key_by_title(ctx: Context, title: str) -> Optional[DeployKey]:
     for key in ctx.gl.deploykeys.list(as_list=False):
         if key.title == title:
+            assert isinstance(key, DeployKey), key
             return key
     return None
 
@@ -320,7 +324,10 @@ def delete_deploy_keys(project: Project, ctx: Context):
 
 
 def ensure_ssh_key_pairs(
-    fetcher_project: Project, source_data_project: Project, json_data_project: Project, ctx: Context,
+    fetcher_project: Project,
+    source_data_project: Project,
+    json_data_project: Project,
+    ctx: Context,
 ):
     """Checks that the SSH key pairs are configured, otherwise configure them.
 
@@ -500,8 +507,9 @@ def take_ownership(schedule: ProjectPipelineSchedule, owner_name: str, ctx: Cont
     if len(owners) == 0:
         raise TakeOwnershipError(new_owner_name=owner_name, schedule=schedule, details="User not found")
 
-    assert len(owners) == 1, owners
+    assert isinstance(owners, list) and len(owners) == 1, owners
     owner = owners[0]
+    assert isinstance(owner, User), owner
 
     with create_impersonation_token(
         owner,
